@@ -40,7 +40,9 @@ AddNetworkRouteDialog::AddNetworkRouteDialog(QWidget *parent, const QString& cap
 
 
 AddNetworkRouteDialog::~AddNetworkRouteDialog()
-{}
+{
+	delete main;
+}
 
 void AddNetworkRouteDialog::accept()
 {
