@@ -1,23 +1,23 @@
 /***************************************************************************
- *    Copyright (C) 2005 by hal9000 <hal9000@evilscientists.de>                             *
-  *   Copyright (C) 2005 by Maurice Massar <vpnc@unix-ag.uni-kl.de>                             *
-  *   Copyright (C) 2005 by Christoph Thielecke <crissi99@gmx.de>                             *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
- ***************************************************************************/
+ *    Copyright (C) 2005 by hal9000 <hal9000@evilscientists.de>                             *
+  *   Copyright (C) 2005 by Maurice Massar <vpnc@unix-ag.uni-kl.de>                             *
+  *   Copyright (C) 2005 by Christoph Thielecke <crissi99@gmx.de>                             *
+ *                                                                         *
+ *   This program is free software; you can redistribute it and/or modify  *
+ *   it under the terms of the GNU General Public License as published by  *
+ *   the Free Software Foundation; either version 2 of the License, or     *
+ *   (at your option) any later version.                                   *
+ *                                                                         *
+ *   This program is distributed in the hope that it will be useful,       *
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
+ *   GNU General Public License for more details.                          *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the                         *
+ *   Free Software Foundation, Inc.,                                       *
+ *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ ***************************************************************************/
 #include "ciscopasswddecoder.h"
 
 #include <qfile.h>
@@ -46,18 +46,14 @@ void CiscoPasswdDecoder::readProfileData(QString& profile, QString& userData, QS
 			if ( !line.startsWith("#") )
 			{
 
-				if (line.startsWith("enc_GroupPwd"))
+				if (line.startsWith("enc_GroupPwd") || line.startsWith("enc_GroupPwd") )
 					groupData=line.section('=',1,1);
-				if (line.startsWith("enc_UserPassword"))
+				if (line.startsWith("enc_UserPassword") || line.startsWith("enc_GroupPwd") )
 					userData=line.section('=',1,1);
-				}
-
 			}
 		}
-		PcfFile.close();
-
-
-
+	}
+	PcfFile.close();
 }
 
 int CiscoPasswdDecoder::hex2bin_c(unsigned int c)
