@@ -46,13 +46,16 @@
 #include "importcertificatedialog.h"
 //END INCLUDES
 
-ImportOpenvpnProfileDialog::ImportOpenvpnProfileDialog(KVpncConfig *config, QWidget *parent, const QString& caption)
+ImportOpenvpnProfileDialog::ImportOpenvpnProfileDialog(KVpncConfig *config, QWidget *parent, const QString& caption, QString file)
 		: KDialogBase( parent, "Import_Cisco_OpenVPN_profile", true, caption,
 		               KDialogBase::Ok|KDialogBase::Cancel, KDialogBase::Ok, true )
 {
-	filename = "";
+	if (!file.isEmpty())
+		filename = file;
+	else
+		filename = "";
 	Pkcs12CertFile="";
-	CertPath="";
+	CertPath="/etc/openvpn";
 	importOk = false;
 	this->config = config;
 
@@ -237,8 +240,12 @@ void ImportOpenvpnProfileDialog::canAccept()
 		while ( !stream.atEnd() )
 		{
 			line = stream.readLine().simplifyWhiteSpace(); // line of text excluding '\n' and replace all white chars with one blank
-			if ( !line.startsWith("#") )
+			line.remove('\"');
+			if ( !line.startsWith("#") && !line.startsWith(";") )
 			{
+				int commentidx = line.find('#');
+				if (commentidx > -1 )
+					line = line.left(commentidx-1);
 
 				if (line.startsWith("remote "))
 				{
@@ -257,9 +264,13 @@ void ImportOpenvpnProfileDialog::canAccept()
 
 				else if (line.startsWith("dev "))
 				{
-					acc->setTunnelDeviceType( line.section(' ', 1,1) ); // tun or tap
-					if (config->KvpncDebugLevel > 0)
-						config->appendLogEntry( i18n( "OpenVPN import: tunnel device type: %1" ).arg(acc->getTunnelDeviceType()),config->debug );
+					QString Type=line.section(' ', 1,1); // tun or tap
+					if (Type == "tun" || Type == "tap") 
+					{
+						acc->setTunnelDeviceType( Type);
+						if (config->KvpncDebugLevel > 0)
+							config->appendLogEntry( i18n( "OpenVPN import: tunnel device type: %1" ).arg(acc->getTunnelDeviceType()),config->debug );
+					}
 				}
 
 				else if (line.startsWith("route "))
@@ -317,10 +328,10 @@ void ImportOpenvpnProfileDialog::canAccept()
 				else if (line.startsWith("cert "))
 				{
 					acc->setAuthType( VpnAccountData::cert );
-					if (CertPath.isEmpty())
-						acc->setX509Certificate( line.section(' ',1,1));
-					else
-						acc->setX509Certificate( CertPath+"/"+line.section(' ',1,1));
+// 					if (CertPath.isEmpty())
+						acc->setX509Certificate( line.section(' ',1));
+// 					else
+// 						acc->setX509Certificate( CertPath+"/"+line.section(' ',1,1));
 					if (config->KvpncDebugLevel > 0)
 						config->appendLogEntry( i18n( "OpenVPN import: certificate: %1" ).arg(acc->getX509Certificate()),config->debug );
 				}
@@ -328,10 +339,10 @@ void ImportOpenvpnProfileDialog::canAccept()
 				else if (line.startsWith("key "))
 				{
 					acc->setAuthType( VpnAccountData::cert );
-					if (CertPath.isEmpty())
-						acc->setPrivateKey(line.section(' ',1,1));
-					else
-						acc->setPrivateKey(CertPath+"/"+line.section(' ',1,1));
+// 					if (CertPath.isEmpty())
+						acc->setPrivateKey(line.section(' ',1));
+// 					else
+// 						acc->setPrivateKey(CertPath+"/"+line.section(' ',1,1));
 					if (config->KvpncDebugLevel > 0)
 						config->appendLogEntry( i18n( "OpenVPN import: PSK in file: %1" ).arg(acc->getPrivateKey()),config->debug );
 				}
@@ -339,10 +350,10 @@ void ImportOpenvpnProfileDialog::canAccept()
 				else if (line.startsWith("ca "))
 				{
 					acc->setAuthType( VpnAccountData::cert );
-					if (CertPath.isEmpty())
-						acc->setCaCertificate(line.section(' ',1,1));
-					else
-						acc->setCaCertificate(CertPath+"/"+line.section(' ',1,1));
+// 					if (CertPath.isEmpty())
+						acc->setCaCertificate(line.section(' ',1));
+// 					else
+// 						acc->setCaCertificate(CertPath+"/"+line.section(' ',1,1));
 					if (config->KvpncDebugLevel > 0)
 						config->appendLogEntry( i18n( "OpenVPN import: CA certificate: %1" ).arg(acc->getCaCertificate()),config->debug );
 				}
@@ -432,28 +443,29 @@ void ImportOpenvpnProfileDialog::canAccept()
 				else if (line.startsWith("pkcs12 "))
 				{
 					acc->setAuthType( VpnAccountData::cert );
-					Pkcs12CertFile =  line.section(' ', 1,1);
+					Pkcs12CertFile =  line.section(' ', 1);
 					if (config->KvpncDebugLevel > 0)
 						config->appendLogEntry( i18n( "OpenVPN import: pkcs12 file found: %1" ).arg(Pkcs12CertFile),config->debug );
 				}
 
 				else if (line.startsWith("cd "))
 				{
-					CertPath= line.section(' ',1,1);
+					CertPath= line.section(' ',1);
 
-					/* we need to put the prefix to all cert paths */
-					if (!acc->getCaCertificate().isEmpty() && !acc->getCaCertificate().startsWith(CertPath))
-						acc->setCaCertificate(CertPath+"/"+acc->getCaCertificate());
-
-					if ( !acc->getX509Certificate().isEmpty() && !acc->getCaCertificate().startsWith(CertPath))
-						acc->setX509Certificate(CertPath+"/"+acc->getX509Certificate());
-
-					if ( !acc->getPreSharedKey().isEmpty() && !acc->getCaCertificate().startsWith(CertPath))
-						acc->setPreSharedKey(CertPath+"/"+acc->getPreSharedKey());
-
-					if (!Pkcs12CertFile.isEmpty() && !acc->getCaCertificate().startsWith(CertPath))
-						Pkcs12CertFile=CertPath+"/"+Pkcs12CertFile;
+// 					/* we need to put the prefix to all cert paths */
+// 					if (!acc->getCaCertificate().isEmpty() && !acc->getCaCertificate().startsWith(CertPath))
+// 						acc->setCaCertificate(CertPath+"/"+acc->getCaCertificate());
+// 
+// 					if ( !acc->getX509Certificate().isEmpty() && !acc->getCaCertificate().startsWith(CertPath))
+// 						acc->setX509Certificate(CertPath+"/"+acc->getX509Certificate());
+// 
+// 					if ( !acc->getPreSharedKey().isEmpty() && !acc->getCaCertificate().startsWith(CertPath))
+// 						acc->setPreSharedKey(CertPath+"/"+acc->getPreSharedKey());
+// 
+// 					if (!Pkcs12CertFile.isEmpty() && !acc->getCaCertificate().startsWith(CertPath))
+// 						Pkcs12CertFile=CertPath+"/"+Pkcs12CertFile;
 
+					acc->setCertPath( CertPath );
 
 					if (config->KvpncDebugLevel > 0)
 						config->appendLogEntry( i18n( "OpenVPN import: certificate prefix found: %1" ).arg(CertPath),config->debug );
@@ -470,9 +482,10 @@ void ImportOpenvpnProfileDialog::canAccept()
 			}
 		}
 		OpenvpnConfigFile.close();
+		importOk = true;
 	}
-
-	importOk = true;
+	else
+		importOk = false;
 
 	if (!Pkcs12CertFile.isEmpty())
 	{
