@@ -32,7 +32,7 @@ class ImportProfileDialog : public KDialogBase
 {
 Q_OBJECT
 public:
-	ImportProfileDialog( KVpncConfig *config, QWidget *parent, const QString& caption);
+	ImportProfileDialog( KVpncConfig *config, QWidget *parent, const QString& caption, QString file);
 	~ImportProfileDialog();
 	
 	void canAccept();
@@ -41,12 +41,13 @@ public:
 	bool importOk;
 	VpnAccountData *acc;
 	ImportProfileDialogBase *main;
+	QFile *f;
 	
 public slots:
-	void accept();	
+	void accept();
 
 private:
-	KVpncConfig* config;
+	KVpncConfig* GlobalConfig;
 
 };
 
