@@ -44,12 +44,21 @@ KVpncConfig::KVpncConfig(QWidget *parent)
 	pathToIp="/sbin/ip";
 	pathToIfconfig="/sbin/ifconfig";
 	pathToRoute="/sbin/route";
+	pathToNetstat="/bin/netstat";
 	AutoConnectProfile="";
 	Vpnc_pid_file = "";
 	Pppd_pid_file = "";
 	lastProfile = "";
 	logfileName = "";
 
+	TmpPassword="";
+	TmpGroupPassword="";
+	TmpUsername="";
+	TmpPrivKeyPassStr="";
+	TmpGatewayIP="";
+	TmpXauthInterPasscode="";
+	TmpPrivateKeyPass="";
+
 	connectSleepDelay = 15;
 	connectSleepRetry = 0;
 	tryConnectTimeout = 10;
@@ -60,6 +69,8 @@ KVpncConfig::KVpncConfig(QWidget *parent)
 	mainwindow_height=200;
 	mainwindow_width=400;
 
+	OpenvpnManagementPort=2222;
+
 	minimizeAfterConnect = true;
 	//showDebugConsole = false;
 	useDefaultPaths = false;
@@ -277,6 +288,7 @@ void KVpncConfig::saveOptions()
 	config->writeEntry( "Path to iputility", pathToIp );
 	config->writeEntry( "Path to ifconfig", pathToIfconfig );
 	config->writeEntry( "Path to route", pathToRoute );
+	config->writeEntry( "Path to netstat", pathToNetstat );
 	config->writeEntry( "Show Statusbar", showStatusBar );
 	config->writeEntry( "Try connect timeout", tryConnectTimeout );
 	config->writeEntry( "Last Profile", lastProfile );
@@ -293,10 +305,11 @@ void KVpncConfig::saveOptions()
 	config->writeEntry( "Auto connect profile", AutoConnectProfile );
 	config->writeEntry( "Do auto connect at startup", doAutoConnectAtStartup );
 	config->writeEntry( "Log viewer font size", LogViewerFontSize );
-  config->writeEntry( "Mainwindow width", parent->width() );
-  config->writeEntry( "Mainwindow height", parent->height() );
-  config->writeEntry( "Mainwindow position x", parent->x() );
-  config->writeEntry( "Mainwindow position y", parent->y() );
+	config->writeEntry( "Mainwindow width", parent->width() );
+	config->writeEntry( "Mainwindow height", parent->height() );
+	config->writeEntry( "Mainwindow position x", parent->x() );
+	config->writeEntry( "Mainwindow position y", parent->y() );
+	config->writeEntry("Openvpn management port", OpenvpnManagementPort );
 	config->writeEntry( "hideOnCloseInfo" ,hideOnCloseInfo);
 //   config->writeEntry( "ToolBar Settings" ,parent->toolBar( "mainToolBar" ));
 	config->writeEntry("Use KWallet",useKwallet);
@@ -592,6 +605,9 @@ void KVpncConfig::saveOptions()
 				config->writeEntry( "Use userdef packet size", it->getMssfix() );
 				config->writeEntry( "Fragment", it->getFragment() );
 				config->writeEntry( "PeerTimeout", it->getPeerTimeout() );
+				config->writeEntry("Disable CCP", it->getDisableCcp() );
+				config->writeEntry("Use smartcard", it->getUseSmardcard() );
+				config->writeEntry("Use Xauth interactive", it->getUseXauthInteractive() );
 
 				appPointer->processEvents();
 
@@ -651,6 +667,7 @@ void KVpncConfig::loadOptions()
 	pathToIp = config->readEntry( "Path to iputility", "/sbin/ip" );
 	pathToIfconfig = config->readEntry( "Path to ifconfig", "/sbin/ifconfig" );
 	pathToRoute = config->readEntry( "Path to route", "/sbin/route" );
+	pathToNetstat = config->readEntry( "Path to netstat", "/bin/netstat" );
 	pathToPppd = config->readEntry ("Path to pppd","/usr/sbin/pppd");
 	pathToPptp = config->readEntry ("Path to pptp","/usr/sbin/pptp");
 	pathToKill = config->readEntry ("Path to kill","/bin/kill");
@@ -682,6 +699,8 @@ void KVpncConfig::loadOptions()
 	WindowSize = QSize( config->readNumEntry( "Mainwindow width", 50 ), this->config->readNumEntry( "Mainwindow height", 50 ) );
 	WindowPos = QPoint ( config->readNumEntry( "Mainwindow position x", 10 ), this->config->readNumEntry( "Mainwindow position y", 50 ) );
 
+	OpenvpnManagementPort = config->readNumEntry("Openvpn management port", 2222 );
+
 	appPointer->processEvents();
 
 	if ( writeLogFile )
@@ -975,6 +994,9 @@ void KVpncConfig::loadOptions()
 			data->setMssfix(config->readNumEntry( "Mssfix", 1300) );
 			data->setFragment( config->readNumEntry( "Fragment", 1300) );
 			data->setPeerTimeout( config->readNumEntry( "PeerTimeout",0) );
+			data->setDisableCcp( config->readBoolEntry("Disable CCP",false) );
+			data->setUseSmardcard( config->readBoolEntry("Use smartcard", false) );
+			data->setUseXauthInteractive(config->readBoolEntry("Use Xauth interactive", false) );
 
 			appPointer->processEvents();
 			AccountList->append( data );
