@@ -68,6 +68,7 @@ public:
 	QString pathToIp;
 	QString pathToIfconfig;
 	QString pathToRoute;
+	QString pathToNetstat;
 	QString AutoConnectProfile;
 	QString RacoonDebugLevel;
 	QString Vpnc_pid_file;
@@ -75,6 +76,14 @@ public:
 	QString lastProfile;
 	QString logfileName;
 
+	QString TmpPassword; //< from enter password dialog
+	QString TmpGroupPassword; //< from enter password dialog
+	QString TmpUsername; //< from enter password dialog
+	QString TmpPrivKeyPassStr;
+	QString TmpGatewayIP;
+	QString TmpXauthInterPasscode; //< from Xauth interactive passcode dialog
+	QString TmpPrivateKeyPass;
+
 	bool minimizeAfterConnect;
 	bool showDebugConsole;
 	bool writeLogFile;
@@ -113,6 +122,7 @@ public:
 	int connectionStartTime;
 	int runningCheckCounter;
 	int runningCheckTimeout;
+	int OpenvpnManagementPort;
 	QPtrList<ToolInfo> *ToolList;
 	QPtrList<VpnAccountData> *AccountList;
 	VpnAccountData *currentProfile;
