@@ -40,6 +40,11 @@ KVpncKicker::KVpncKicker( QWidget* parent, const char *name )
 
 KVpncKicker::~KVpncKicker() {}
 
+void KVpncKicker::closeEvent( QCloseEvent*  )
+{
+//	emit e;
+}
+
 void KVpncKicker::setStatus( int status ) {
 	if ( status == connecting ) {
 		setPixmap( connectingIcon );
@@ -52,9 +57,9 @@ void KVpncKicker::setStatus( int status ) {
 }
 
 void KVpncKicker::initDockWindow() {
-	disconnectedIcon = loadIcon( "kvpnc-disconnected");
-	connectedIcon = loadIcon( "kvpnc-connected"  );
-	connectingIcon = loadIcon( "kvpnc-connecting" );
+	disconnectedIcon = loadIcon( "disconnected");
+	connectedIcon = loadIcon( "connected"  );
+	connectingIcon = loadIcon( "connecting" );
 	//setFixedSize( DOCK_WIDTH, DOCK_HEIGHT );
 	setPixmap( disconnectedIcon );
 	QToolTip::add(this, i18n("Disconnected"));
