@@ -308,6 +308,7 @@ void NewProfileDialog::importCertificate()
 {
 	//FIXME make dynamiclly
 	ImportCertificateDialog importdlg(  this, i18n("Import certificate...").ascii(), GlobalConfig);
+	//dlg.resize(dlg.height(),600);
 	//int result =
 	importdlg.exec();
 }
@@ -733,8 +734,9 @@ QString NewProfileDialog::getName()
 
 void NewProfileDialog::importPcfFileClicked()
 {
-	ImportProfileDialog dlg(GlobalConfig,this, i18n("Import Cisco PCF Profile..."));
+	ImportProfileDialog dlg(GlobalConfig,this, i18n("Import Cisco PCF Profile..."),"");
 	dlg.exec();
+	dlg.resize(800,dlg.height());
 }
 
 void NewProfileDialog::groupPasswordContentChanged()
