@@ -38,6 +38,7 @@
 #include <iostream>
 
 #include <kstddirs.h>
+#include <kinputdialog.h>
 
 #include "kvpncconfig.h"
 #include "networkinterface.h"
@@ -92,7 +93,7 @@ NewProfileWizard::NewProfileWizard(KVpncConfig* GlobalConfig)
 	useNoDeflate=true;
 	savePsk=false;
 	connectaftercreating=true;
-	deamonavailable=false;
+	daemonavailable=false;
 	enterdatamanually=false;
 	importOK=false;
 
@@ -143,8 +144,8 @@ void NewProfileWizard::accept()
 		}
 		else	if ( profileData->getConnectionType() == VpnAccountData::openvpn )
 		{
-			importProfile(VpnAccountData::openvpn);
-			if (importOK)
+			
+			if (importProfile(VpnAccountData::openvpn) == true)
 				newProfileCreated=true;
 			else
 				newProfileCreated=false;
@@ -467,16 +468,28 @@ void NewProfileWizard::next ()
 			}
 
 			VpnAccountData * it;
-			for ( it = GlobalConfig->AccountList->first(); it; it = GlobalConfig->AccountList->next() )
-			{
-				if ( it->getName() == Name )
-				{
-					KMessageBox::error ( this, i18n( "Profile name already exists!" ), i18n( "Name Already Exists" ) );
-					GlobalConfig->appendLogEntry(i18n( "Profile name already exists!" ) ,GlobalConfig->error);
 
-					nameOk = FALSE;
-					break;
+			while (nameOk==false)
+			{
+				for ( it = GlobalConfig->AccountList->first(); it; it = GlobalConfig->AccountList->next() )
+				{
+					if ( it->getName() == Name )
+					{
+						//account->setName( QString( account->getName() + "_2" ) );
+						// 				KMessageBox::information ( this, i18n( "Profile name exists!\n It will be renamed to \"%1\"." ).arg( account->getName() ), i18n( "Name exist, renamed" ) );
+						KMessageBox::error ( this, i18n( "Profile name exists!"), i18n( "Name Exists" ) );
+						
+						QString newName = KInputDialog::getText   (   i18n("New Name"),i18n("New name for profile:"),QString(Name+="_2"),&ok);
+						
+						if (!Name.isEmpty())
+						{
+							nameOk=true;
+							break;
+						}
+					}
+					nameOk=true;
 				}
+				nameOk=true;
 			}
 
 			if ( nameOk )
@@ -662,15 +675,15 @@ void NewProfileWizard::next ()
 				if (it->PathToExec.section('/',-1) == bin )
 				{
 					if (GlobalConfig->KvpncDebugLevel > 0)
-						GlobalConfig->appendLogEntry(i18n("The required deamon (%1) is available, you will be able to use this connection.").arg(bin),KVpncConfig::info);
-					deamonavailable=true;
+						GlobalConfig->appendLogEntry(i18n("The required daemon (%1) is available, you will be able to use this connection.").arg(bin),KVpncConfig::info);
+					daemonavailable=true;
 				}
 				else
 				{
-					KMessageBox::information ( this, i18n("The required deamon (%1) isn't available, you will not be able to use this connection until the deamon is not installed.").arg(bin));
+					KMessageBox::information ( this, i18n("The required daemon (%1) isn't available, you will not be able to use this connection until the daemon is not installed.").arg(bin));
 					if (GlobalConfig->KvpncDebugLevel > 0)
-						GlobalConfig->appendLogEntry(i18n("The required deamon (%1) isn't available, you will not be able to use this connection until the deamon is not installed.").arg(bin),KVpncConfig::error);
-					deamonavailable=false;
+						GlobalConfig->appendLogEntry(i18n("The required daemon (%1) isn't available, you will not be able to use this connection until the daemon is not installed.").arg(bin),KVpncConfig::error);
+					daemonavailable=false;
 					removePage(newprofilewizardconnectoptionspage);
 				}
 
@@ -701,15 +714,15 @@ void NewProfileWizard::next ()
 				if ( pppd_and_pptp_available )
 				{
 					// programs are installed
-					deamonavailable=true;
+					daemonavailable=true;
 					if (GlobalConfig->KvpncDebugLevel > 0)
-						GlobalConfig->appendLogEntry(i18n("The required deamons (%2 and %2) are available.").arg("pppd").arg("pptp"),KVpncConfig::info);
+						GlobalConfig->appendLogEntry(i18n("The required daemons (%2 and %2) are available.").arg("pppd").arg("pptp"),KVpncConfig::info);
 				}
 				else
 				{
-					KMessageBox::information ( this, i18n("The required deamons (%1 and %2) aren't available, you will not be able to use this connection until the deamons are not installed.").arg("pppd").arg("pptpd"));
-					GlobalConfig->appendLogEntry(i18n("The required deamons (%1 and %2) are not available, connect will be disabled.").arg("pppd").arg("pptpd"),KVpncConfig::error);
-					deamonavailable=false;
+					KMessageBox::information ( this, i18n("The required daemons (%1 and %2) aren't available, you will not be able to use this connection until the daemons are not installed.").arg("pppd").arg("pptpd"));
+					GlobalConfig->appendLogEntry(i18n("The required daemons (%1 and %2) are not available, connect will be disabled.").arg("pppd").arg("pptpd"),KVpncConfig::error);
+					daemonavailable=false;
 					removePage(newprofilewizardconnectoptionspage);
 				}
 			}
@@ -1026,6 +1039,11 @@ void NewProfileWizard::next ()
 		profileData->setDisableMPPEComp(newprofilewizardpptppagecontent->UseNoMPPECompressionCheckbox->isChecked());
 		profileData->setKeepDefaultRoute( newprofilewizardpptppagecontent->KeepDefaultRouteCheckBox->isChecked());
 
+		newprofilewizardnetworkcontent->LabelRemoteNetwork->hide();
+		newprofilewizardnetworkcontent->RemoteNetMaskComboBox->hide();
+		newprofilewizardnetworkcontent->RemoteNetAddrLineEdit->hide();
+		newprofilewizardnetworkcontent->RemoteNetDividetextLabel->hide();
+
 		insertPage(newprofilewizarduserpage,"<b>"+i18n("User settings")+"</b>", indexOf(currentpage)+1);
 
 	}
@@ -1185,7 +1203,7 @@ void NewProfileWizard::next ()
 	{
 		msg=i18n("These fields must be filled in:\n");
 		bool validAddr = true;
-		if ( ( profileData->getConnectionType() == VpnAccountData::freeswan || profileData->getConnectionType() == VpnAccountData::racoon || profileData->getConnectionType() == VpnAccountData::pptp ) )
+		if ( ( profileData->getConnectionType() == VpnAccountData::freeswan || profileData->getConnectionType() == VpnAccountData::racoon) )
 		{
 			if  ( !newprofilewizardnetworkcontent->RemoteNetAddrLineEdit->text().isEmpty() )
 			{
@@ -1476,6 +1494,11 @@ bool NewProfileWizard::getFinished()
 	return finished;
 }
 
+// void NewProfileDialog::reject()
+// {
+// 	
+// }
+
 void NewProfileWizard::showPage( QWidget* page )
 {
 	currentpage= page;
@@ -1645,7 +1668,7 @@ bool NewProfileWizard::importProfile(VpnAccountData::ConnectionType ConnType)
 
 	if ( ConnType == VpnAccountData::cisco)
 	{
-		ImportProfileDialog dlg(GlobalConfig, this,i18n("Import Cisco PCF profile"));
+		ImportProfileDialog dlg(GlobalConfig, this,i18n("Import Cisco PCF profile"),"");
 		dlg.exec();
 		importOK = dlg.importOk;
 		if ( importOK )
@@ -1663,7 +1686,7 @@ bool NewProfileWizard::importProfile(VpnAccountData::ConnectionType ConnType)
 	}
 	if ( ConnType == VpnAccountData::openvpn)
 	{
-		ImportOpenvpnProfileDialog dlg(GlobalConfig, this,i18n("Import OpenVPN profile"));
+		ImportOpenvpnProfileDialog dlg(GlobalConfig, this,i18n("Import OpenVPN profile"),"");
 		dlg.exec();
 		importOK = dlg.importOk;
 		if ( importOK )
@@ -1722,7 +1745,7 @@ bool NewProfileWizard::importP12Certificate()
 		QString certificate = QString("mykeys_" + dlg.certName + ".pem");
 
 		newprofilewizardcertcontent->CaCertpathURLRequester->setURL (CaCertFullPath);
-		newprofilewizardcertcontent->privkeypathURLRequester->setURL (certpath+"/"+certificate);
+		newprofilewizardcertcontent->privkeypathURLRequester->setURL (certificate);
 
 		if (profileData->getConnectionType() == VpnAccountData::openvpn)
 			newprofilewizardcertcontent->PrivkeyPasswordEdit->setText(importpassword);
