@@ -40,20 +40,26 @@ public:
 
 private:
 	QProcess *CollectToolInfoProcess;
+	QProcess *CollectOpenvpnCapabilitiesProcess;
 	QStringList SearchPathList;
 	bool collectRunning;
+	bool collectOpenvpnCapabilitiesRunning;
 
 public:
 	QString Name; //< Name of the tool
 	QString Version; //< Version number of the tool
 	QString PathToExec; //< Path to executable
+	QString Capabilities;
 	bool collectToolInfo(); //< Collects information of the tool
 	void addSearchPath(const QString &path); //< Adds a path for searching
+	void getOpenvpnCapabilities();
 
 
 private slots:
 	void readStdOutCollectToolInfo();
 	void readStdErrCollectToolInfo();
+	void readStdOutCollectOpenvpnCapabilies();
+	void readStdErrCollectOpenvpnCapabilies();
 	void processFinished();
 
 };
