@@ -22,7 +22,6 @@
 
 #include <qobject.h>
 #include <qprocess.h>
-#include <qdns.h>
 #include <qvaluelist.h>
 #include "kvpncconfig.h"
 #include "kvpnc.h"
@@ -50,50 +49,49 @@ public:
 	bool isValidIPv4BroadcastAddress(QString Address);
 	bool tunDevExists();
 	bool createTunDev();
-  bool loadKernelModule(QString Name,QApplication *app);
-	bool isValidNetworkDevice(QString NetworkDevice);
+	bool loadKernelModule(QString Name,QApplication *app);
 	bool doChmod(QString file, QString mode);
 	QStringList getOpenvpnCiphers();
 	QPtrList<ToolInfo>* getToolList();
 	ToolInfo* getToolInfo(KVpncConfig *GlobalConfig, QString name);
-	QString resolveName(QString Name,QApplication *app);
+	QString resolveName(QString Name);
 	QString removeSpecialCharsForFilename(QString filename);
+	QString getNameAndPidOfProgramListen(int port);
 
 public slots:
 	void readStdOutCreateTunDev();
 	void readStdErrCreateTunDev();
-	void readStdOutNetworkDeviceTest();
-	void readStdErrNetworkDeviceTest();
 	void readStdOutLoadKernelModule();
 	void readStdErrLoadKernelModule();
 	void readStdOutToolsTest();
 	void readStdErrToolsTest();
 	void readStdOutRetriveOpenvpnCiphers();
 	void readStdErrRetriveOpenvpnCiphers();
-	void dnsLookupHelper();
-	void processHasFinished();
+	void readStdOutGetNameAndPidOfProgramListen();
+	void readStdErrGetNameAndPidOfProgramListen();
 
 private:
-	bool validNetworkDevice;
 	bool modprobeSuccess;
 	bool toolsTestSuccess;
 	bool retrieveOpenvpnCiphers;
+	bool retrieveNameAndPidOfProgramListen;
 	QString tooltest_logfile;
 	QProcess *ModprobeProcess;
 	QProcess *createProcess;
 	QProcess *NetworkDeviceTestProcess;
 	QProcess *toolsTestProcess;
 	QProcess *OpenvpnCiphersProcess;
+	QProcess *NameAndPidOfProgramListenProcess;
 	QString resolvedIP;
 	bool resolveFinished;
-	QDns *myDns;
 	QValueList<QHostAddress> list;
 	QStringList *env;
 	KVpncConfig *config;
 	KTempFile *tmpfile;
 	bool retrieveValidNetworkdevice;
 	QStringList OpenvpnCiphers;
-
+	QString NameAndPidOfProgramListen;
+	int ListenPort;
 };
 
 #endif
