@@ -64,7 +64,6 @@ VpnAccountData::VpnAccountData( ConnectionType ConnType,const QString& Name)
 	usePerfectForwardSecrety=false;
 	useNtDomainName=false;
 	useApplicationVersion=false;
-	useLocalPort=false;
 	useSingleDes=false;
 	useGlobalIpsecSecret=false;
 	doPingIP=false;
@@ -111,7 +110,6 @@ VpnAccountData::VpnAccountData( ConnectionType ConnType,const QString& Name)
 	RemoteNetAddr="";
 	saveUserPassword=true;
 	savePsk=true;
-	useAdvancedSettings=false;
 	useIkeGroup=false;
 	usePerfectForwardSecrety=false;
 	useNtDomainName=false;
@@ -163,7 +161,11 @@ VpnAccountData::VpnAccountData( ConnectionType ConnType,const QString& Name)
 	disableOpportunisticEncryption=false;
 	useMssfix=false;
 	useFragment=false;
+	disableCcp=false;
+	useXauthInteractive=false;
+	savePrivateKeyPassword=false;
 
+	PeerTimeout=60;
 	ReconnectDelay=5;
 	connectionStatusInterval=20;
 	Mtu=1500;
@@ -750,6 +752,26 @@ int VpnAccountData::getPeerTimeout() const
 	return PeerTimeout;
 }
 
+bool VpnAccountData::getDisableCcp() const
+{
+	return disableCcp;
+}
+
+bool VpnAccountData::getUseSmardcard() const
+{
+	return useSmardcard;
+}
+
+bool VpnAccountData::getUseXauthInteractive() const
+{
+	return useXauthInteractive;
+}
+
+bool VpnAccountData::getSavePrivateKeyPassword() const
+{
+	return savePrivateKeyPassword;
+}
+
 /* set methods */
 void VpnAccountData::setConnectionType( ConnectionType type )
 {
@@ -1315,3 +1337,23 @@ void VpnAccountData::setPeerTimeout( int PeerTimeout )
 {
 	this->PeerTimeout = PeerTimeout;
 }
+
+void VpnAccountData::setDisableCcp( bool disableCcp )
+{
+	this->disableCcp = disableCcp;
+}
+
+void VpnAccountData::setUseSmardcard( bool useSmardcard)
+{
+	this->useSmardcard = useSmardcard;
+}
+
+void VpnAccountData::setUseXauthInteractive( bool useXauthInteractive)
+{
+	this->useXauthInteractive = useXauthInteractive;
+}
+
+void VpnAccountData::setSavePrivateKeyPassword( bool savePrivateKeyPassword)
+{
+	this->savePrivateKeyPassword = savePrivateKeyPassword;
+}
