@@ -165,6 +165,10 @@ public:
 	bool getDisableOpportunisticEncryption() const;
 	bool getUseMssfix() const;
 	bool getUseFragment() const;
+	bool getDisableCcp() const;
+	bool getUseSmardcard() const;
+	bool getUseXauthInteractive() const;
+	bool getSavePrivateKeyPassword() const;
 
 	/**
 	 *   Sets the connection type
@@ -330,6 +334,10 @@ public:
 	void setMssfix( int Mssfix );
 	void setFragment( int Fragment );
 	void setPeerTimeout( int PeerTimeout );
+	void setDisableCcp( bool disableCcp );
+	void setUseSmardcard( bool useSmardcard );
+	void setUseXauthInteractive( bool useXauthInteractive );
+	void setSavePrivateKeyPassword ( bool savePrivateKeyPassword );
 
 protected:
 	QString Name; //< Name of the profile
@@ -434,6 +442,10 @@ protected:
 	bool disableOpportunisticEncryption;
 	bool useMssfix;
 	bool useFragment;
+	bool disableCcp;
+	bool useSmardcard;
+	bool useXauthInteractive;
+	bool savePrivateKeyPassword;
 	int Mtu;
 	int UdpPort; //< Port number of UDP port
 	int LocalPort; //< userdefined local port
